from typing import Dict, Optional

from pydantic import BaseModel, ConfigDict



class Coupon(BaseModel):
    """The resource representing a Coupon."""

    amount_off: Optional[float] = None

    deleted: Optional[bool] = None

    id: Optional[str] = None

    metadata: Optional[Dict[str, str]] = None

    name: Optional[str] = None

    percent_off: Optional[float] = None

    model_config = ConfigDict(protected_namespaces=())



from typing import Optional

from pydantic import BaseModel, ConfigDict



class OutputFile(BaseModel):
    """Output file contents."""

    contents: Optional[str] = None

    name: Optional[str] = None

    model_config = ConfigDict(protected_namespaces=())




from pydantic import BaseModel, ConfigDict



class EntityGetDistance(BaseModel):
    """The response from the `EntitiesGetDistance` command."""

    max_distance: float

    min_distance: float

    model_config = ConfigDict(protected_namespaces=())



from typing import List, Optional

from pydantic import BaseModel, ConfigDict

from ..models.output_file import OutputFile


class CodeOutput(BaseModel):
    """Output of the code being executed."""

    output_files: Optional[List[OutputFile]] = None

    stderr: Optional[str] = None

    stdout: Optional[str] = None

    model_config = ConfigDict(protected_namespaces=())
